from .units import Units
from .library import Library
from .log_output_mode import LogOutputMode
from .protobufs import main_pb2 as protobufs
from .tools import Tools
from .device_db_source_type import DeviceDbSourceType
from .measurement import Measurement
from .convert_exception import convert_exception
from .exceptions import *
from .firmware_version import FirmwareVersion
from .rotation_direction import RotationDirection
__version__ = "2.4.0"



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from typing import TYPE_CHECKING, Set
from ..call import call, call_async

from ..protobufs import main_pb2

if TYPE_CHECKING:
    from .device import Device


class Warnings:
    """
    Class used to check and reset warnings and faults on device or axis.
    """

    def __init__(self, device: 'Device', axis_number: int):
        self._device = device
        self._axis_number = axis_number

    def get_flags(
            self
    ) -> Set[str]:
        """
        Returns current warnings and faults on axis or device.

        Returns:
            Retrieved warnings and faults. Refer to WarningFlags to check a particular flag.
        """
        request = main_pb2.DeviceGetWarningsRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.axis = self._axis_number
        request.clear = False
        response = main_pb2.DeviceGetWarningsResponse()
        call("device/get_warnings", request, response)
        return set(response.flags)

    async def get_flags_async(
            self
    ) -> Set[str]:
        """
        Returns current warnings and faults on axis or device.

        Returns:
            Retrieved warnings and faults. Refer to WarningFlags to check a particular flag.
        """
        request = main_pb2.DeviceGetWarningsRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.axis = self._axis_number
        request.clear = False
        response = main_pb2.DeviceGetWarningsResponse()
        await call_async("device/get_warnings", request, response)
        return set(response.flags)

    def clear_flags(
            self
    ) -> Set[str]:
        """
        Clears (acknowledges) current warnings and faults on axis or device and returns them.

        Returns:
            Warnings and faults before clearing. Refer to WarningFlags to check a particular flag.
        """
        request = main_pb2.DeviceGetWarningsRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.axis = self._axis_number
        request.clear = True
        response = main_pb2.DeviceGetWarningsResponse()
        call("device/get_warnings", request, response)
        return set(response.flags)

    async def clear_flags_async(
            self
    ) -> Set[str]:
        """
        Clears (acknowledges) current warnings and faults on axis or device and returns them.

        Returns:
            Warnings and faults before clearing. Refer to WarningFlags to check a particular flag.
        """
        request = main_pb2.DeviceGetWarningsRequest()
        request.interface_id = self._device.connection.interface_id
        request.device = self._device.device_address
        request.axis = self._axis_number
        request.clear = True
        response = main_pb2.DeviceGetWarningsResponse()
        await call_async("device/get_warnings", request, response)
        return set(response.flags)



from setuptools import setup, find_packages

from os import path


def read_from_file(*filename):
    with open(path.join(*filename), 'r') as f:
        return f.read()


setup(
    name='zaber_motion',
    version='2.4.0',
    packages=find_packages(exclude=["test*", "test_*", "*_test*"]),
    package_data={
        '': ['*.pyi', 'py.typed']
    },
    description='A library for communicating with Zaber devices',
    long_description=read_from_file('DESCRIPTION.md'),
    long_description_content_type="text/markdown",
    url='https://gitlab.com/ZaberTech/zaber-motion-lib',
    author='Zaber Technologies Inc.',
    author_email='contact@zaber.com',
    license='Apache Software License v2.0',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Topic :: Software Development :: Libraries',
        'Programming Language :: Python :: 3',
    ],
    keywords='',
    python_requires='>=3.6',
    install_requires=[
        'protobuf==3.13.0',
        'rx>=3.0.0'
    ],
    extras_require={
        'dev': [
            'pytest',
            'pylint',
            'pycodestyle',
            'setuptools',
            'wheel',
            'twine==1.15.0'
        ],
        ':platform_system=="Windows"': [
            'zaber_motion_bindings_windows==2.4.0'
        ],
        ':platform_system=="Linux"': [
            'zaber_motion_bindings_linux==2.4.0'
        ],
        ':platform_system=="Darwin"': [
            'zaber_motion_bindings_darwin==2.4.0'
        ]
    }
)



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from .call import call_sync
from .protobufs import main_pb2
from .log_output_mode import LogOutputMode
from .device_db_source_type import DeviceDbSourceType


class Library:
    """
    Access class to general library information and configuration.
    """

    @staticmethod
    def set_log_output(
            mode: LogOutputMode,
            file_path: str = ""
    ) -> None:
        """
        Sets library logging output.

        Args:
            mode: Logging output mode.
            file_path: Path of the file to open.
        """
        request = main_pb2.SetLogOutputRequest()
        request.mode = mode.value
        request.file_path = file_path
        call_sync("logging/set_output", request)

    @staticmethod
    def set_device_db_source(
            source_type: DeviceDbSourceType,
            url_or_file_path: str = ""
    ) -> None:
        """
        Sets source of Device DB data. Allows selection of a web service or a local file.

        Args:
            source_type: Source type.
            url_or_file_path: URL of the web service or path to the local file.
                Leave empty for the default URL of Zaber web service.
        """
        request = main_pb2.SetDeviceDbSourceRequest()
        request.source_type = source_type.value
        request.url_or_file_path = url_or_file_path
        call_sync("device_db/set_source", request)

    @staticmethod
    def enable_device_db_store(
            store_location: str = ""
    ) -> None:
        """
        Enables Device DB store.
        The store uses filesystem to save information obtained from the Device DB.
        The stored data are later used instead of the Device DB.

        Args:
            store_location: Specifies relative or absolute path of the folder used by the store.
                If left empty defaults to a folder in user home directory.
                Must be accessible by the process.
        """
        request = main_pb2.ToggleDeviceDbStoreRequest()
        request.toggle_on = True
        request.store_location = store_location
        call_sync("device_db/toggle_store", request)

    @staticmethod
    def disable_device_db_store(
    ) -> None:
        """
        Disables Device DB store.
        """
        request = main_pb2.ToggleDeviceDbStoreRequest()
        call_sync("device_db/toggle_store", request)
